pickled_cucumber library

Classes

And
And annotation. Used to mark a method as a And step.
Background
Background annotation. Used to mark a method as a Background step.
But
But annotation. Used to mark a method as a But step.
GherkinAnnotation
Base class for all Gherkin annotations.
Given
Given annotation. Used to mark a method as a Given step.
PickledCucumber
Engine class to run Cucumber tests with Dart
StepDefinition
StepDefinition annotation. Used to mark a class as a step definition.
Then
Then annotation. Used to mark a method as a Then step.
When
When annotation. Used to mark a method as a When step.