But class

But annotation. Used to mark a method as a But step.

Inheritance

Constructors

But(String value)
Creates a new instance of But.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value of the annotation. eg. @Given('I have a step') => I have a step
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited